The other logical fields have their own macros, so the logical datapath
field might as well have one.

Signed-off-by: Ben Pfaff <b...@nicira.com>
---
 ovn/controller/physical.c | 10 +++++-----
 ovn/controller/rule.h     |  7 ++++---
 2 files changed, 9 insertions(+), 8 deletions(-)

diff --git a/ovn/controller/rule.h b/ovn/controller/rule.h
index 3998994..a7bd71f 100644
--- a/ovn/controller/rule.h
+++ b/ovn/controller/rule.h
@@ -37,9 +37,10 @@ struct controller_ctx;
 struct hmap;
 struct uuid;
 
-/* Logical ports. */
-#define MFF_LOG_INPORT  MFF_REG6 /* Logical input port. */
-#define MFF_LOG_OUTPORT MFF_REG7 /* Logical output port. */
+/* Logical fields. */
+#define MFF_LOG_DATAPATH MFF_METADATA /* Logical datapath (64 bits). */
+#define MFF_LOG_INPORT   MFF_REG6     /* Logical input port (32 bits). */
+#define MFF_LOG_OUTPORT  MFF_REG7     /* Logical output port (32 bits). */
 
 void rule_init(void);
 void rule_run(struct controller_ctx *, struct hmap *flow_table);
diff --git a/ovn/controller/physical.c b/ovn/controller/physical.c
index 2dc96ab..e284a6a 100644
--- a/ovn/controller/physical.c
+++ b/ovn/controller/physical.c
@@ -127,7 +127,7 @@ physical_run(struct controller_ctx *ctx, const struct 
ovsrec_bridge *br_int,
         }
 
         /* Translate the logical datapath into the form we use in
-         * MFF_METADATA. */
+         * MFF_LOG_DATAPATH. */
         uint32_t ldp = ldp_to_integer(&binding->logical_datapath);
         if (!ldp) {
             continue;
@@ -147,8 +147,8 @@ physical_run(struct controller_ctx *ctx, const struct 
ovsrec_bridge *br_int,
              * traffic, match on the tags and then strip the tag.
              * Priority 100 is for traffic belonging to VMs.
              *
              * For both types of traffic: set MFF_LOG_INPORT to the
              * logical input port, MFF_METADATA to the logical datapath, and
              * resubmit into the logical pipeline starting at table 16. */
             match_init_catchall(&match);
             ofpbuf_clear(&ofpacts);
@@ -157,9 +157,9 @@ physical_run(struct controller_ctx *ctx, const struct 
ovsrec_bridge *br_int,
                 match_set_dl_vlan(&match, htons(tag));
             }
 
-            /* Set MFF_METADATA. */
+            /* Set MFF_LOG_DATAPATH. */
             struct ofpact_set_field *sf = ofpact_put_SET_FIELD(&ofpacts);
-            sf->field = mf_from_id(MFF_METADATA);
+            sf->field = mf_from_id(MFF_LOG_DATAPATH);
             sf->value.be64 = htonll(ldp);
             sf->mask.be64 = OVS_BE64_MAX;
 
@@ -147,8 +147,8 @@ physical_run(struct controller_ctx *ctx, const struct 
              * Priority 100 is for traffic belonging to VMs.
              *
-             * For both types of traffic: set MFF_LOG_INPORT to the
-             * logical input port, MFF_METADATA to the logical datapath, and
+             * For both types of traffic: set MFF_LOG_INPORT to the logical
+             * input port, MFF_LOG_DATAPATH to the logical datapath, and
              * resubmit into the logical pipeline starting at table 16. */
             match_init_catchall(&match);
-- 
2.1.3

_______________________________________________
dev mailing list
dev@openvswitch.org
http://openvswitch.org/mailman/listinfo/dev

Reply via email to